Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2017)

Unified Diff: chrome/browser/google/google_update_win.h

Issue 1214603005: Simplify update error message support HTML. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: rebased Created 5 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/google/google_update_win.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/google/google_update_win.h
diff --git a/chrome/browser/google/google_update_win.h b/chrome/browser/google/google_update_win.h
index 0e02c76338509c39e8d1bc3a196d88a68c8b1491..a27e49ddc9ea421a1924a5cfe474f684bd0518a5 100644
--- a/chrome/browser/google/google_update_win.h
+++ b/chrome/browser/google/google_update_win.h
@@ -76,11 +76,13 @@ class UpdateCheckDelegate {
virtual void OnUpgradeComplete(const base::string16& new_version) = 0;
// Invoked following an unrecoverable error, indicated by |error_code|.
// |error_message|, if not empty, contains a localized string that may be
// presented to the user explaining the nature of the error. |new_version|, if
// not empty, indicates the version to which an upgrade attempt was made.
grt (UTC plus 2) 2015/07/09 14:33:09 Ideally, this comment should explain the contract
bcwhite 2015/07/09 14:54:00 Done.
+ // |new_version|, if not empty, indicates the version to which an upgrade
+ // attempt was made.
virtual void OnError(GoogleUpdateErrorCode error_code,
- const base::string16& error_message,
+ const base::string16& html_error_message,
const base::string16& new_version) = 0;
protected:
« no previous file with comments | « no previous file | chrome/browser/google/google_update_win.cc » ('j') | no next file with comments »
@@ -76,11 +76,13 @@ class UpdateCheckDelegate {
virtual void OnUpgradeComplete(const base::string16& new_version) = 0;
// Invoked following an unrecoverable error, indicated by |error_code|.
- // |error_message|, if not empty, contains a localized string that may be
- // presented to the user explaining the nature of the error. |new_version|, if
- // not empty, indicates the version to which an upgrade attempt was made.
+ // |html_error_message|, if not empty, contains a localized string that may
+ // be presented to the user via html explaining the nature of the error; it
+ // should include the error code because that will not be displayed otherwise.
grt (UTC plus 2) 2015/07/09 14:33:09 Ideally, this comment should explain the contract
bcwhite 2015/07/09 14:54:00 Done.

Powered by Google App Engine
This is Rietveld 408576698